suggest imports
===============
`suggest` should be called in a project folder, . Currently only Rust (Cargo)
projects are supported. This is an early version of something that will
hopefully increase awareness of available packages in Python, NodeJS, Rust, Go
and other languages.
